@@ -13,10 +13,12 @@ class CTkSlider(tkinter.Frame):
                  bg_color=None,
                  border_color=None,
                  fg_color=CTkColorManager.SLIDER_BG,
+                 progress_color=None,
                  button_color=CTkColorManager.MAIN,
                  button_hover_color=CTkColorManager.MAIN_HOVER,
                  from_=0,
                  to=1,
+                 number_of_steps=None,
                  width=160,
                  height=16,
                  border_width=5,
@@ -30,6 +32,7 @@ class CTkSlider(tkinter.Frame):
         self.bg_color = self.detect_color_of_master() if bg_color is None else bg_color
         self.border_color = self.bg_color if border_color is None else border_color
         self.fg_color = fg_color
+        self.progress_color = progress_color if progress_color is not None else fg_color
         self.button_color = self.bg_color if button_color is None else button_color
         self.button_hover_color = self.bg_color if button_hover_color is None else button_hover_color
 
@@ -41,6 +44,7 @@ class CTkSlider(tkinter.Frame):
         self.hover_state = False
         self.from_ = from_
         self.to = to
+        self.number_of_steps = number_of_steps
         self.output_value = self.from_ + (self.value * (self.to - self.from_))
 
         self.configure(width=self.width, height=self.height)
@@ -48,7 +52,7 @@ class CTkSlider(tkinter.Frame):
             self.configure(cursor="pointinghand")
 
         self.canvas = tkinter.Canvas(master=self,
-                                     highlightthicknes=0,
+                                     highlightthickness=0,
                                      width=self.width,
                                      height=self.height)
         self.canvas.place(x=0, y=0)
@@ -91,9 +95,9 @@ class CTkSlider(tkinter.Frame):
 
         if no_color_updates is False:
             self.canvas.configure(bg=CTkColorManager.single_color(self.bg_color, self.appearance_mode))
-            print(self.border_color)
             self.canvas.itemconfig("border_parts", fill=CTkColorManager.single_color(self.border_color, self.appearance_mode))
             self.canvas.itemconfig("inner_parts", fill=CTkColorManager.single_color(self.fg_color, self.appearance_mode))
+            self.canvas.itemconfig("progress_parts", fill=CTkColorManager.single_color(self.progress_color, self.appearance_mode))
             self.canvas.itemconfig("button_parts", fill=CTkColorManager.single_color(self.button_color, self.appearance_mode))
 
     def draw_with_polygon_shapes(self):
@@ -120,12 +124,30 @@ class CTkSlider(tkinter.Frame):
         if not self.canvas.find_withtag("inner_parts"):
             self.canvas.create_line((0, 0, 0, 0), tags=("inner_line_1", "inner_parts"))
 
+        if self.progress_color != self.fg_color:
+            if not self.canvas.find_withtag("progress_parts"):
+                self.canvas.create_line((0, 0, 0, 0), tags=("inner_line_progress", "progress_parts"))
+                self.canvas.tag_raise("button_parts")
+        else:
+            self.canvas.delete("progress_parts")
+
         self.canvas.coords("inner_line_1",
                            (self.height / 2,
                             self.height / 2,
                             self.width - self.height / 2 + coordinate_shift,
                             self.height / 2))
-        self.canvas.itemconfig("inner_line_1",
+
+        if self.progress_color != self.fg_color:
+            self.canvas.coords("inner_line_progress",
+                               (self.height / 2,
+                                self.height / 2,
+                                ((self.width + coordinate_shift - self.height) * self.value + self.height / 2),
+                                self.height / 2))
+
+        self.canvas.itemconfig("inner_parts",
+                               capstyle=tkinter.ROUND,
+                               width=self.height - self.border_width * 2 + width_reduced)
+        self.canvas.itemconfig("progress_parts",
                                capstyle=tkinter.ROUND,
                                width=self.height - self.border_width * 2 + width_reduced)
 
@@ -171,18 +193,38 @@ class CTkSlider(tkinter.Frame):
 
         # foreground
         if not self.canvas.find_withtag("inner_parts"):
-            self.canvas.create_oval((0, 0, 0, 0), tags=("inner_oval_1", "inner_parts"), width=0)
-            self.canvas.create_rectangle((0, 0, 0, 0), tags=("inner_rect_1", "inner_parts"), width=0)
+            self.canvas.create_rectangle((0, 0, 0, 0), tags=("inner_rect_2", "inner_parts"), width=0)
             self.canvas.create_oval((0, 0, 0, 0), tags=("inner_oval_2", "inner_parts"), width=0)
 
+        # progress parts
+        if not self.canvas.find_withtag("inner_oval_1"):
+            self.canvas.delete("inner_oval_1", "inner_rect_1")
+
+            if self.progress_color != self.fg_color:
+                self.canvas.create_oval((0, 0, 0, 0), tags=("inner_oval_1", "progress_parts"), width=0)
+                self.canvas.create_rectangle((0, 0, 0, 0), tags=("inner_rect_1", "progress_parts"), width=0)
+            else:
+                self.canvas.create_oval((0, 0, 0, 0), tags=("inner_oval_1", "inner_parts"), width=0)
+
+        if self.progress_color != self.fg_color:
+            self.canvas.coords("inner_rect_1", (self.height / 2,
+                                                self.border_width,
+                                                (self.width - self.height) * self.value + (self.height / 2 + rect_bottom_right_shift),
+                                                self.height - self.border_width + rect_bottom_right_shift))
+            self.canvas.coords("inner_rect_2", ((self.width - self.height) * self.value + (self.height / 2 + rect_bottom_right_shift),
+                                                self.border_width,
+                                                self.width - (self.height / 2 + rect_bottom_right_shift),
+                                                self.height - self.border_width + rect_bottom_right_shift))
+        else:
+            self.canvas.coords("inner_rect_2", (self.height/2,
+                                                self.border_width,
+                                                self.width-(self.height/2 + rect_bottom_right_shift),
+                                                self.height-self.border_width + rect_bottom_right_shift))
+
         self.canvas.coords("inner_oval_1", (self.border_width,
                                             self.border_width,
-                                            self.height-self.border_width + oval_bottom_right_shift,
-                                            self.height-self.border_width + oval_bottom_right_shift))
-        self.canvas.coords("inner_rect_1", (self.height/2,
-                                            self.border_width,
-                                            self.width-(self.height/2 + rect_bottom_right_shift),
-                                            self.height-self.border_width + rect_bottom_right_shift))
+                                            self.height - self.border_width + oval_bottom_right_shift,
+                                            self.height - self.border_width + oval_bottom_right_shift))
         self.canvas.coords("inner_oval_2", (self.width-self.height+self.border_width,
                                             self.border_width,
                                             self.width-self.border_width + oval_bottom_right_shift,
@@ -206,7 +248,8 @@ class CTkSlider(tkinter.Frame):
         if self.value < 0:
             self.value = 0
 
-        self.output_value = self.from_ + (self.value * (self.to - self.from_))
+        self.output_value = self.round_to_step_size(self.from_ + (self.value * (self.to - self.from_)))
+        self.value = (self.output_value - self.from_) / (self.to - self.from_)
 
         self.draw(no_color_updates=True)
 
@@ -221,11 +264,24 @@ class CTkSlider(tkinter.Frame):
         self.hover_state = False
         self.canvas.itemconfig("button_parts", fill=CTkColorManager.single_color(self.button_color, self.appearance_mode))
 
+    def round_to_step_size(self, value):
+        if self.number_of_steps is not None:
+            step_size = (self.to - self.from_) / self.number_of_steps
+            value = self.to - (round((self.to - value) / step_size) * step_size)
+            return value
+        else:
+            return value
+
     def get(self):
         return self.output_value
 
     def set(self, output_value):
-        self.output_value = output_value
+        if output_value > self.to:
+            output_value = self.to
+        elif output_value < self.from_:
+            output_value = self.from_
+
+        self.output_value = self.round_to_step_size(output_value)
         self.value = (self.output_value - self.from_) / (self.to - self.from_)
 
         self.draw(no_color_updates=True)
@@ -233,6 +289,74 @@ class CTkSlider(tkinter.Frame):
         if self.callback_function is not None:
             self.callback_function(self.output_value)
 
+    def config(self, *args, **kwargs):
+        self.configure(*args, **kwargs)
+
+    def configure(self, *args, **kwargs):
+        require_redraw = False  # some attribute changes require a call of self.draw() at the end
+
+        if "fg_color" in kwargs:
+            self.fg_color = kwargs["fg_color"]
+            require_redraw = True
+            del kwargs["fg_color"]
+
+        if "bg_color" in kwargs:
+            if kwargs["bg_color"] is None:
+                self.bg_color = self.detect_color_of_master()
+            else:
+                self.bg_color = kwargs["bg_color"]
+            require_redraw = True
+            del kwargs["bg_color"]
+
+        if "progress_color" in kwargs:
+            if kwargs["progress_color"] is None:
+                self.progress_color = self.fg_color
+            else:
+                self.progress_color = kwargs["progress_color"]
+            require_redraw = True
+            del kwargs["progress_color"]
+
+        if "button_color" in kwargs:
+            self.button_color = kwargs["button_color"]
+            require_redraw = True
+            del kwargs["button_color"]
+
+        if "button_hover_color" in kwargs:
+            self.button_hover_color = kwargs["button_hover_color"]
+            require_redraw = True
+            del kwargs["button_hover_color"]
+
+        if "border_color" in kwargs:
+            self.border_color = kwargs["border_color"]
+            require_redraw = True
+            del kwargs["border_color"]
+
+        if "border_width" in kwargs:
+            self.border_width = kwargs["border_width"]
+            require_redraw = True
+            del kwargs["border_width"]
+
+        if "from_" in kwargs:
+            self.from_ = kwargs["from_"]
+            del kwargs["from_"]
+
+        if "to" in kwargs:
+            self.to = kwargs["to"]
+            del kwargs["to"]
+
+        if "number_of_steps" in kwargs:
+            self.number_of_steps = kwargs["number_of_steps"]
+            del kwargs["number_of_steps"]
+
+        if "command" in kwargs:
+            self.callback_function = kwargs["command"]
+            del kwargs["command"]
+
+        super().configure(*args, **kwargs)
+
+        if require_redraw:
+            self.draw()
+
     def change_appearance_mode(self, mode_string):
         if mode_string.lower() == "dark":
             self.appearance_mode = 1
